//
//  GBFileItem.h
//  gBrowser
//
//  Created by Andreas Schwarz on Thu Apr 18 2002.
//  Copyright (c) 2001 __MyCompanyName__. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#import <AASFilesystemTools/AASFilesystemTools.h>
#import "GBMarkableItemProtocol.h"





@interface GBFileItem : AASBasicInfoFileItem <GBMarkableItemProtocol> {
    /// More file info ///	
    NSString *fileType;
    NSString *kind;
    
    NSImage *fileIcon;
    NSImage *genericIcon;
    char hasCustomIcon;
    
    NSString *modificationDateString;
    
    NSDate *creationDate;
    NSString *creationDateString;
    NSDate *EXIFDate;
    NSString *EXIFDateString;
    
    NSString *fileSizeString;
    NSString *dataForkSizeString;
    BOOL fileSizeFound;
    unsigned long long fileSize;
    unsigned long long dataForkSize;
    
    NSString *resolvedFileType;
	
    char isImage;
    char isText;
    char isMovie;
    char isMusic;
    char isInTrash;
    
	NSInteger imageOrientation;
    
    /// Image information ///
    NSString *dimensionsString;
    NSString *colorModelString;
    NSString *resolution;
    NSString *megapixelString;
    NSString *ICCProfile;
	double megapixels;
	NSSize dimensions;
    
    BOOL foundImageData;
	char imageMetadataEditable;
    
	NSDictionary *imageProperties;
	NSMutableDictionary *marks;
}


#pragma mark -
#pragma mark File Information

@property(readonly) NSString * fileSizeString;
@property(readonly) NSString * dataForkSizeString;

@property(readonly) unsigned long long fileSize;
@property(readonly) unsigned long long dataForkSize;

@property(readonly) NSString * kindString;

@property(readonly) NSString * modificationDateString;
@property(readonly) NSString * creationDateString;
@property(readonly) NSDate * creationDate;
@property(readonly) NSDate * EXIFDate;
@property(readonly) NSString * EXIFDateString;

@property(readonly) NSString * displayNamePath;

@property(readonly) BOOL isImage;
@property(readonly) BOOL isMovie;
@property(readonly) BOOL isText;
@property(readonly) BOOL isMusic;

@property(readonly) BOOL isMedia;

@property(readonly) BOOL isInTrash;

@property(readonly) GBFileItem *preferredApplication;
@property(readonly) GBFileItem *editorApplication;




#pragma mark -
#pragma mark Image Information

@property (readonly) BOOL hasEditableImageMetadata;

@property(readonly) NSString * dimensionsString;
@property(readonly) NSString * colorModelString;
@property(readonly) NSString * resolutionString;
@property(readonly) NSString * megapixelString;
@property(readonly) NSString * ICCString;

@property(readonly) NSInteger imageOrientation;
- (BOOL)setImageOrientation:(NSInteger)newOrientation;

@property(readonly) double megapixels;
@property(readonly) NSSize dimensions;




#pragma mark -
#pragma mark Icons and Thumbnails

@property(readonly) NSImage * fileIcon;
@property(readonly) NSImage * genericIcon;

@property(readonly) BOOL hasCustomIcon;

@property(readonly) NSData * thumbnailData;
@property(readonly) BOOL thumbnailDataExists;




#pragma mark -


- (BOOL)countOfFiles:(NSUInteger *)files folders:(NSUInteger *)folders total:(NSUInteger *)total fileFilter:(AASFileFilter *)fileFilter directoryFilter:(AASFileFilter *)directoryFilter;




#pragma mark -
#pragma mark Actions


- (BOOL)setAsDesktopPicture:(NSInteger)screenNumber;




#pragma mark -
#pragma mark Sorting Functions

- (NSComparisonResult)sortFilesByName:(id)otherItem;
- (NSComparisonResult)sortFilesByPath:(id)otherItem;

CFComparisonResult GBFileSortByContext(const void *obj1, const void *obj2, void *context);
CFComparisonResult GBFileSort(id obj1, id obj2, NSUInteger type, NSUInteger reverseSort, NSUInteger folderSort);


#pragma mark -
#pragma mark Filter Class Methods

+ (NSNumber *)filterImages:(GBFileItem *)file;
+ (NSNumber *)filterNoFolders:(GBFileItem *)file;
+ (NSNumber *)filterSupportedTypes:(GBFileItem *)file;


@end








